@@ -2,9 +2,9 @@ __all__ = (
     "hist",
     "fisher_info",
     "cramer_rao_uncert",
-    "gaussianity",
+    "cut",
 )
 
+from relaxed.ops.cuts import cut
 from relaxed.ops.fisher_information import cramer_rao_uncert, fisher_info
 from relaxed.ops.histograms import hist
-from relaxed.ops.likelihood_gaussianity import gaussianity
